<template>
    <div id="docx">
        <div v-if="noFile" class="empty">{{ text }}</div>
        <div v-else ref="file"></div>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/districView.js'
import { getLocalBLob } from '@/utils/getLocalFile.js'
const docx = require('docx-preview')
window.JSZip = require('jszip')
export default {
    name: 'Docx',
    props: {
        fileUrl: {
            default: '',
            type: String,
            required: true,
        },
        fileId: {
            default: '',
            type: String,
            required: true,
        },
    },
    data() {
        return {
            noFile: false,
            text: '',
        }
    },
    mounted() {
        this.initDocx()
    },
    watch: {
        fileUrl(newVal, oldVal) {
            this.initDocx()
        }
    },
    methods: {
        async initDocx() {
            if (this.fileId) {
                this.noFile = false
                const bLob = await apiList.previewFile(this.fileId)
                console.log(bLob, 'bLob')
                docx.renderAsync(bLob, this.$refs.file) // 渲染到页面预览
            } else if (this.fileUrl) {
                this.noFile = false
                const bLob = await getLocalBLob(this.fileUrl)
                docx.renderAsync(bLob, this.$refs.file)
                this.noFile = false // 渲染到页面预览
            } else if (!this.fileUrl && !this.fileId) {
                let searchDate = sessionStorage.getItem('searchDate')
                searchDate = JSON.parse(searchDate)
                this.noFile = true
                this.text = `${searchDate.year}年第${searchDate.quarter}季度暂无报告`
            }
            this.$emit('closeLoading')
        },
    },
}
</script>

<style lang="scss">
#docx {
    width: 100%;
    height: 100%;

    .docx-wrapper {
        padding: 0 !important;
        width: 100%;

        .docx {
            width: 100% !important;
        }

        section.docx {
            margin-bottom: 0 !important;
        }
    }



    table {
        width: 100% !important;

        * {
            font-size: 20PX !important;
        }

        td {
            padding: 20px 15px !important;
        }
        span {
            line-height: 24PX;
        }
    }

    .empty {
        width: 100%;
        height: 100%;
        color: #fff;
        display: flex;
        justify-content: center;
        align-items: center;
        font-size: 20px;
    }
}
</style>
